Dictionaries
::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   dictionaries1.rst
   dictionarycounters.rst
   dictionariesandfiles.rst
   loopinganddictionaries.rst
   advancedtextparsing.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   mixedupcode.rst
   writecode.rst
